# soagen

Struct-of-Arrays for C++.

[![Sponsor](docs/images/badge-sponsor.svg)][sponsor]
[![Gitter](docs/images/badge-gitter.svg)][gitter]

<br><br>

<p align="center">
	<strong>✨&#xFE0F; This README is a stub. Please see the HTML documentation: <a href="https://marzer.github.io/soagen/">marzer.github.io/soagen</a>✨&#xFE0F;</strong>
</p>

<br><br>

[gitter]: https://gitter.im/marzer/community
[sponsor]: https://github.com/sponsors/marzer
